@@ -1,5 +1,6 @@
 import errno
 import os
+import posixpath
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -31,7 +32,6 @@ def bytesio_len(obj: "BytesIO") -> Optional[int]:
 
 class GitFileSystem(AbstractFileSystem):
     # pylint: disable=abstract-method
-    sep = os.sep
     cachable = False
 
     def __init__(
@@ -53,21 +53,13 @@ class GitFileSystem(AbstractFileSystem):
             resolved = resolver(scm, rev or "HEAD")
             tree_obj = scm.pygit2.get_tree_obj(rev=resolved)
             trie = GitTrie(tree_obj, resolved)
-            path = scm.root_dir
-        else:
-            assert path
 
         self.trie = trie
-        self.root_dir = path
         self.rev = self.trie.rev
 
     def _get_key(self, path: str) -> Tuple[str, ...]:
-        from scmrepo.utils import relpath
-
-        if os.path.isabs(path):
-            path = relpath(path, self.root_dir)
-        relparts = path.split(os.sep)
-        if relparts == ["."]:
+        relparts = path.split(self.sep)
+        if relparts == [self.root_marker]:
             return ()
         return tuple(relparts)
 
@@ -101,7 +93,7 @@ class GitFileSystem(AbstractFileSystem):
         try:
             return {
                 **self.trie.info(key),
-                "name": os.path.join(self.root_dir, self.sep.join(key)),
+                "name": path,
             }
         except KeyError:
             raise FileNotFoundError(
@@ -145,15 +137,13 @@ class GitFileSystem(AbstractFileSystem):
 
         key = self._get_key(top)
         for prefix, dirs, files in self.trie.walk(key, topdown=topdown):
-            root = self.root_dir
+            root = self.sep.join(prefix) if prefix else ""
 
-            if prefix:
-                root = os.path.join(root, os.sep.join(prefix))
             if detail:
                 yield (
                     root,
-                    {d: self.info(os.path.join(root, d)) for d in dirs},
-                    {f: self.info(os.path.join(root, f)) for f in files},
+                    {d: self.info(posixpath.join(root, d)) for d in dirs},
+                    {f: self.info(posixpath.join(root, f)) for f in files},
                 )
             else:
                 yield root, dirs, files
