@@ -291,7 +291,7 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
     def is_ignored(self, path: "Union[str, os.PathLike[str]]") -> bool:
         rel = relpath(path, self.root_dir)
         if os.name == "nt":
-            rel.replace("\\", "/")
+            rel = rel.replace("\\", "/")
         return self.repo.path_is_ignored(rel)
 
     def set_ref(
@@ -317,9 +317,17 @@ class Pygit2Backend(BaseGitBackend):  # pylint:disable=abstract-method
             )
 
     def get_ref(self, name, follow: bool = True) -> Optional[str]:
-        from pygit2 import GIT_OBJ_COMMIT, GIT_REF_SYMBOLIC, Tag
+        from pygit2 import (
+            GIT_OBJ_COMMIT,
+            GIT_REF_SYMBOLIC,
+            InvalidSpecError,
+            Tag,
+        )
 
-        ref = self.repo.references.get(name)
+        try:
+            ref = self.repo.references.get(name)
+        except InvalidSpecError:
+            return None
         if not ref:
             return None
         if follow and ref.type == GIT_REF_SYMBOLIC:
